@@ -113,15 +113,19 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         return []
 
     def _generateDescription(self, obj, **args):
-        if self._script.utilities.isZombie(obj) \
-           or obj != orca_state.locusOfFocus:
+        if self._script.utilities.isZombie(obj):
+            return []
+
+        role = args.get('role', obj.getRole())
+        if obj != orca_state.locusOfFocus:
+            if role in [pyatspi.ROLE_ALERT, pyatspi.ROLE_DIALOG]:
+                return super()._generateDescription(obj, **args)
             return []
 
         formatType = args.get('formatType')
         if formatType == 'basicWhereAmI' and self._script.utilities.isLiveRegion(obj):
             return self._script.liveRegionManager.generateLiveRegionDescription(obj, **args)
 
-        role = args.get('role', obj.getRole())
         if role == pyatspi.ROLE_TEXT and formatType != 'basicWhereAmI':
             return []
 
@@ -147,7 +151,9 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         return []
 
     def _generateLabelOrName(self, obj, **args):
-        if self._script.utilities.isTextBlockElement(obj):
+        if self._script.utilities.isTextBlockElement(obj) \
+           and not self._script.utilities.isLandmark(obj) \
+           and not self._script.utilities.isDPub(obj):
             return []
 
         if self._script.utilities.inDocumentContent(obj) and obj.name:
@@ -159,7 +165,8 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
     def _generateName(self, obj, **args):
         if self._script.utilities.isTextBlockElement(obj) \
-           and not self._script.utilities.isLandmark(obj):
+           and not self._script.utilities.isLandmark(obj) \
+           and not self._script.utilities.isDPub(obj):
             return []
 
         # TODO - JD: Once the formatting strings are vastly cleaned up
@@ -249,6 +256,12 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
         return super().getLocalizedRoleName(obj, **args)
 
+    def _generateRealActiveDescendantDisplayedText(self, obj, **args):
+        if not self._script.utilities.inDocumentContent(obj):
+            return super()._generateRealActiveDescendantDisplayedText(obj, **args)
+
+        return self._generateDisplayedText(obj, **args)
+
     def _generateRoleName(self, obj, **args):
         if not self._script.utilities.inDocumentContent(obj):
             return super()._generateRoleName(obj, **args)
@@ -284,7 +297,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         if not force:
             doNotSpeak.append(pyatspi.ROLE_TABLE_CELL)
             doNotSpeak.append(pyatspi.ROLE_TEXT)
-            doNotSpeak.append('ROLE_STATIC')
+            doNotSpeak.append(pyatspi.ROLE_STATIC)
             if args.get('formatType', 'unfocused') != 'basicWhereAmI':
                 doNotSpeak.append(pyatspi.ROLE_LIST_ITEM)
                 doNotSpeak.append(pyatspi.ROLE_LIST)
@@ -302,8 +315,14 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                 text = self._script.utilities.queryNonEmptyText(obj)
                 if text and end not in [None, text.characterCount]:
                     return []
-            if role not in doNotSpeak:
+            if role in [pyatspi.ROLE_ENTRY, pyatspi.ROLE_PASSWORD_TEXT]:
                 result.append(self.getLocalizedRoleName(obj, **args))
+            elif obj.parent and not obj.parent.getState().contains(pyatspi.STATE_EDITABLE):
+                if lastKey not in ["Home", "End", "Up", "Down", "Left", "Right", "Page_Up", "Page_Down"]:
+                    result.append(object_properties.ROLE_EDITABLE_CONTENT)
+            elif role not in doNotSpeak:
+                result.append(self.getLocalizedRoleName(obj, **args))
+            if result:
                 result.extend(acss)
 
         elif role == pyatspi.ROLE_HEADING:
@@ -425,9 +444,6 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         if obj.getRole() in menuRoles:
             return super()._generatePositionInList(obj, **args)
 
-        if self._script.utilities.isTextBlockElement(obj):
-            return []
-
         if self._script.utilities.isEditableComboBox(obj):
             return []
 
@@ -478,8 +494,6 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             oldRole = self._overrideRole('default', args)
         elif self._script.utilities.isLink(obj):
             oldRole = self._overrideRole(pyatspi.ROLE_LINK, args)
-        elif self._script.utilities.isAnchor(obj):
-            oldRole = 'ROLE_STATIC'
         elif self._script.utilities.treatAsDiv(obj, offset=args.get('startOffset')):
             oldRole = self._overrideRole(pyatspi.ROLE_SECTION, args)
         else:
